@@ -6,6 +6,7 @@ use warnings;
 use Dancer qw(:syntax !before !after);
 use Dancer::Plugin;
 use Dancer::Plugin::DBIC;
+use Dancer::Plugin::Auth::Extensible;
 
 use Interchange6::Class;
 use Interchange6::Cart;
@@ -16,11 +17,11 @@ Dancer::Plugin::Interchange6 - Interchange6 Shop Plugin for Dancer
 
 =head1 VERSION
 
-Version 0.001
+Version 0.002
 
 =cut
 
-our $VERSION = '0.001';
+our $VERSION = '0.002';
 
 =head1 HOOKS
 
@@ -147,7 +148,7 @@ register shop_product_class => sub {
 
 register cart => sub {
     my $name = 'main';
-    my $cart;
+    my ($user_ref, $cart);
 
     if (@_ == 1) {
         $name = $_[0];
@@ -158,6 +159,14 @@ register cart => sub {
                                        session_id => session->id,
                                        run_hooks => sub {execute_hook(@_)});
 
+    if ($user_ref = logged_in_user) {
+        $cart->load(users_id => $user_ref->users_id,
+                    session_id => session->id);
+    }
+    else {
+        $cart->load(session_id => session->id);
+    }
+
     return $cart;
 };
 
